<?php
/*
Plugin Name: Related Posts Shortcodes
Description: Generates shortcodes to display related posts based on the current post category. Includes shortcodes to display single related posts as well as a shortcode to display 5 related posts together. Shortcodes: [short-code1] to [short-code10] for single related posts, [Related-Posts] for displaying 5 related posts together.
Plugin URI: https://teckshop.net/our-plugins/
Author: Teckshop.net
Author URI: https://Teckshop.net/
Version: 1.0.1
*/




if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}

// Register a custom image size
function rps_register_image_sizes()
{
    add_image_size('related-post-thumb', 150, 100, true); // 150px wide by 100px tall, crop mode
}
add_action('after_setup_theme', 'rps_register_image_sizes');

function rps_register_shortcodes()
{
    for ($i = 1; $i <= 10; $i++) {
        add_shortcode('short-code' . $i, 'rps_display_related_post_' . $i);
    }
}
add_action('init', 'rps_register_shortcodes');

for ($i = 1; $i <= 10; $i++) {
    eval ('
    function rps_display_related_post_' . $i . '($atts) {
        return rps_get_related_post(' . $i . ');
    }
    ');
}

function rps_get_related_post($number)
{
    global $post;

    $categories = wp_get_post_categories($post->ID);
    if (empty($categories)) {
        return ''; // No categories, no related posts.
    }

    $args = array(
        'category__in' => $categories,
        'post__not_in' => array($post->ID),
        'posts_per_page' => 1,
        'offset' => $number - 1 // Skip the first ($number - 1) posts.
    );

    $related_posts = new WP_Query($args);

    if ($related_posts->have_posts()) {
        $related_posts->the_post();
        $output = '
        <style>
            @media (max-width: 768px) {
                .Teckshop-related-posts {
                    padding: 4px 2px 2px 2px;
                }
                .Teckshop-rp-link {
                    font-size: 14px !important;
                    margin-top: 2px;
                }
				.Teckshop-related-posttitle-multi{
				font-size: 14px !important;
				}
                .Teckshop-rp-image {
                    margin-left: 5px;
                    margin-top: 12px;
					width: 180px !important; /* Set width to make it rectangular */

                }
                .Teckshop-related-postimage {
                    margin-right: 10px !important;
                }
				
            }
            .Teckshop-related-posts {
                display: flex;
                border: 1px dashed #9b1717;
                border-radius: 5px;
                position: relative;
                padding: 9px;
                height: auto;
                margin-top: 20px;
                margin-bottom: 12px;
                background-color: #fffdf9;
            }
            .Teckshop-related-posts:before {
                content: "Also read";
                position: absolute;
                top: -12px;
                font-size: 14px;
                color: #cb0000;
                left: 10px;
                background: #fff;
                padding: 0 4px;
                font-weight: 500;
                border-radius: 50px;
            }
            .Teckshop-related-post {
                display: flex;
            }
            .Teckshop-related-posttitle {
                font-size: 18px;
                line-height: 1.5em;
                font-weight: 600;
                margin-top: 5px;
                text-decoration: none;
                color: #333;
            }
            .Teckshop-rp-image {
			max-width: 150px;
                width: 100px !important; /* Set width to make it rectangular */
                border-radius: 4px !important;
                margin: 8px 10px 0 0;
                box-shadow: 0px 1px 8px #70707096 !important;
            }
            .Teckshop-related-posttitle {
                font-size: 20px;
                line-height: 1.5em;
                font-weight: 600;
                margin-top: 5px;
            }
            a.Teckshop-rp-link {
                color: black;
                font-size: 16px;
                font-weight: 600;
                text-decoration: none;
            }
			
.Teckshop-related-posts-shadow {
    box-shadow: 0px 1px 6px #d7d7d7 !important;
}.Teckshop-related-posts-box-multi {
    border-left: 1px solid #e6e6e6;
    border-right: 1px solid #e6e6e6;
    border-bottom: 1px solid #e6e6e6;
    border-radius: 0 0 4px 4px;
    margin: 20px 0;
}.Teckshop-related-posts-multi-heading {

    width: 100% !important;
    background-color:  #d11919 !important;
    padding: 8px 10px !important;
    margin: 0 !important;
    font-size: 19px !important;
    color: #fff !important;
    font-weight: bold !important;
    border-radius: 4px 4px 0 0 !important;
}.Teckshop-related-posts-multi-inner-box {
    margin: 10px;
}.Teckshop-rp-link-multi {
    color: #202020;
    font-weight: 600;
    font-size: 18px;
}.Teckshop-rp-link-multi {
    color: #202020;
    font-weight: 600;
    font-size: 18px;
}
.Teckshop-related-post-multi {
    display: flex;
    column-gap: 12px;
    width: 100%;
    margin-top: 18px;
}img.Teckshop-rp-image-multi {
border-radius: 5px;
    width: 92px;
    max-width: 92px;
    height: auto;
    display: block;
    box-shadow: 0px 1px 8px #70707096 !important;
}


        </style>

        <div class="Teckshop-related-posts">
            <div class="Teckshop-related-post">
                <div class="Teckshop-related-postimage">
                    <a href="' . get_the_permalink() . '">
                        ' . get_the_post_thumbnail(null, 'related-post-thumb', array('class' => 'Teckshop-rp-image')) . '
                    </a>
                </div>
                <div class="Teckshop-related-postcontent">
                    <a class="Teckshop-rp-link" href="' . get_the_permalink() . '">' . get_the_title() . '</a>
                </div>
            </div>
        </div>';
        wp_reset_postdata();
        return $output;
    } else {
        return ''; // No related posts found.
    }
}
function rps_display_related_posts($atts)
{
    global $post;

    $categories = wp_get_post_categories($post->ID);
    if (empty($categories)) {
        return ''; // No categories, no related posts.
    }

    $args = array(
        'category__in' => $categories,
        'post__not_in' => array($post->ID),
        'posts_per_page' => 5 // Display 5 related posts
    );

    $related_posts = new WP_Query($args);

    if ($related_posts->have_posts()) {
        $output = '
        <div class="Teckshop-related-posts-box-multi Teckshop-related-posts-shadow">
            <h2 class="Teckshop-related-posts-multi-heading">सम्बंधित ख़बरें</h2>
            <div class="Teckshop-related-posts-multi-inner-box">';

        while ($related_posts->have_posts()) {
            $related_posts->the_post();
            $output .= '
                <a class="Teckshop-rp-link-multi" href="' . get_the_permalink() . '">
                    <div class="Teckshop-related-post-multi">
                        <div class="Teckshop-related-postimage-multi">
                            ' . get_the_post_thumbnail(null, 'related-post-thumb', array('class' => 'Teckshop-rp-image-multi')) . '
                        </div>
                        <div class="Teckshop-related-posttitle-multi">' . get_the_title() . '</div>
                    </div>
                </a>';
        }

        $output .= '
        </div>
        <div style="text-align: right; font-size: 14px; font-weight: 500; margin: 10px;">
            Powerd By <a href="https://teckshop.net/our-plugins/" target="_blank">Teckshop⚡</a>
        </div>
    </div>';


        wp_reset_postdata();
        return $output;
    } else {
        return ''; // No related posts found.
    }
}
add_shortcode('Related-Posts', 'rps_display_related_posts');

// Add settings page
function custom_shortcodes_settings_menu() {
    add_options_page(
        'Custom Shortcodes Settings',
        'Custom Shortcodes',
        'manage_options',
        'custom-shortcodes-settings',
        'custom_shortcodes_settings_page'
    );
}
add_action('admin_menu', 'custom_shortcodes_settings_menu');

function custom_shortcodes_settings_page() {
    ?>
    <div class="wrap">
        <h1>Related Posts Settings</h1>
        <form method="post" action="options.php">
            <?php
            settings_fields('custom_shortcodes_settings_group');
            do_settings_sections('custom-shortcodes-settings');
            submit_button();
            ?>
        </form>
    </div>
    <?php
}

// Register settings
function custom_shortcodes_register_settings() {
    register_setting('custom_shortcodes_settings_group', 'custom_shortcodes_also_read_count');
    register_setting('custom_shortcodes_settings_group', 'custom_shortcodes_enable_related_posts');

    add_settings_section('custom_shortcodes_main_section', 'Main Settings', null, 'custom-shortcodes-settings');

    add_settings_field(
        'custom_shortcodes_also_read_count',
        'Number of Also Read Sections',
        'custom_shortcodes_also_read_count_callback',
        'custom-shortcodes-settings',
        'custom_shortcodes_main_section'
    );

    add_settings_field(
        'custom_shortcodes_enable_related_posts',
        'Enable Related Posts',
        'custom_shortcodes_enable_related_posts_callback',
        'custom-shortcodes-settings',
        'custom_shortcodes_main_section'
    );
}
add_action('admin_init', 'custom_shortcodes_register_settings');

function custom_shortcodes_also_read_count_callback() {
    $value = get_option('custom_shortcodes_also_read_count', 0);
    echo '<select name="custom_shortcodes_also_read_count">';
    for ($i = 0; $i <= 5; $i++) {
        echo '<option value="' . $i . '"' . selected($value, $i, false) . '>' . $i . '</option>';
    }
    echo '</select>';
}

function custom_shortcodes_enable_related_posts_callback() {
    $value = get_option('custom_shortcodes_enable_related_posts', 0);
    echo '<input type="checkbox" name="custom_shortcodes_enable_related_posts" value="1"' . checked(1, $value, false) . '>';
}

// Modify post content
function custom_shortcodes_modify_content($content) {
    if (!is_single()) {
        return $content;
    }

    $also_read_count = get_option('custom_shortcodes_also_read_count', 0);
    $enable_related_posts = get_option('custom_shortcodes_enable_related_posts', 0);

    $split_content = explode('</p>', $content);
    $num_sections = count($split_content);
    
    // Place "Related Posts" in the middle
    if ($enable_related_posts && $num_sections > 1) {
        $middle_index = floor($num_sections / 2);
        $split_content[$middle_index] .= do_shortcode('[Related-Posts]');
    }

    if ($also_read_count > 0) {
        $interval = ceil($num_sections / ($also_read_count + 1));
        $modified_content = '';
        $shortcode_index = 1;

        foreach ($split_content as $index => $paragraph) {
            $modified_content .= $paragraph . '</p>';
            if ($shortcode_index <= $also_read_count && ($index + 1) % $interval == 0) {
                $modified_content .= do_shortcode('[short-code' . $shortcode_index . ']');
                $shortcode_index++;
            }
        }

        $content = $modified_content;
    } else {
        $content = implode('</p>', $split_content);
    }

    return $content;
}
add_filter('the_content', 'custom_shortcodes_modify_content');
?>